@@ -214,7 +214,9 @@ define!({
 
         Attr(AttrSelector),
 
-        Pseudo(PseudoSelector),
+        PseudoClass(PseudoClassSelector),
+
+        PseudoElement(PseudoElementSelector),
 
         At(AtSelector),
     }
@@ -259,13 +261,18 @@ define!({
         pub b_raw: Option<JsWord>,
     }
 
-    pub struct PseudoSelector {
+    pub struct PseudoClassSelector {
         pub span: Span,
-        pub is_element: bool,
         pub name: Ident,
         pub children: Option<PseudoSelectorChildren>,
     }
 
+    pub struct PseudoElementSelector {
+        pub span: Span,
+        pub name: Ident,
+        pub children: Option<Tokens>,
+    }
+
     pub struct IdSelector {
         pub span: Span,
         pub text: Ident,
